@@ -1,4 +1,4 @@
 from pdme.measurement.dot_measure import DotMeasurement
 from pdme.measurement.oscillating_dipole import OscillatingDipole, OscillatingDipoleArrangement
 
-__all__ = ['DotMeasurement', 'OscillatingDipole', 'OscillatingDipoleArrangement']
+__all__ = ['DotMeasurement', 'DotRangeMeasurement', 'OscillatingDipole', 'OscillatingDipoleArrangement']
