@@ -30,7 +30,21 @@ class FixedMagnitudeModel(Model):
 		self.rng = numpy.random.default_rng()
 
 	def __repr__(self) -> str:
-		return f'FixedMagnitudeModel({self.xmin}, {self.xmax}, {self.ymin}, {self.ymax}, {self.zmin}, {self.zmax}, {self.n()})'
+		return f'FixedMagnitudeModel({self.xmin}, {self.xmax}, {self.ymin}, {self.ymax}, {self.zmin}, {self.zmax}, {self.pfixed}, {self.n()})'
+
+	def solution_single_dipole(self, pt: numpy.ndarray) -> OscillatingDipole:
+		# assume length is 6, who needs error checking.
+		p_theta = pt[0]
+		p_phi = pt[1]
+		s = pt[2:5]
+		w = pt[5]
+
+		p = numpy.array([
+			self.pfixed * numpy.sin(p_theta) * numpy.cos(p_phi),
+			self.pfixed * numpy.sin(p_theta) * numpy.sin(p_phi),
+			self.pfixed * numpy.cos(p_theta)
+		])
+		return OscillatingDipole(p, s, w)
 
 	def point_length(self) -> int:
 		'''
@@ -48,6 +62,23 @@ class FixedMagnitudeModel(Model):
 		s_pts = numpy.array((self.rng.uniform(self.xmin, self.xmax), self.rng.uniform(self.ymin, self.ymax), self.rng.uniform(self.zmin, self.zmax)))
 		return OscillatingDipoleArrangement([OscillatingDipole(numpy.array([px, py, pz]), s_pts, frequency)])
 
+	def get_n_single_dipoles(self, n: int, max_frequency: float) -> numpy.ndarray:
+		# psw
+
+		theta = 2 * numpy.pi * self.rng.random(n)
+		phi = numpy.arccos(2 * self.rng.random(n) - 1)
+		px = self.pfixed * numpy.cos(theta) * numpy.sin(phi)
+		py = self.pfixed * numpy.sin(theta) * numpy.sin(phi)
+		pz = self.pfixed * numpy.cos(phi)
+
+		sx = self.rng.uniform(self.xmin, self.xmax, n)
+		sy = self.rng.uniform(self.ymin, self.ymax, n)
+		sz = self.rng.uniform(self.zmin, self.zmax, n)
+
+		w = self.rng.uniform(1, max_frequency, n)
+
+		return numpy.array([px, py, pz, sx, sy, sz, w]).T
+
 	def n(self) -> int:
 		return self._n
 
